/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package demo.jaxrs.client;

import java.io.File;
import java.io.InputStream;
import java.net.URL;

import org.apache.cxf.jaxrs.client.JAXRSClientFactory;

import demo.jaxrs.SaleService;

import demo.jaxrs.precash.Product;
import demo.jaxrs.precash.Item;
import demo.jaxrs.precash.Cart;

import javax.ws.rs.core.Response;

public final class Client {

    private static final long[] barcodeList= { 
	  1l,
	  2l,
	  5l,
	  8l
    };
      
    private static final int[] quantityList= {
	  5,
	 10,
	  1,
	  2
    };      
      
    private Client() {
    }

    public static void main(String args[]) throws Exception {
	// specific code
	SaleService store = JAXRSClientFactory.create("http://localhost:9000", SaleService.class);
	
	// non-specific code
	Cart cart = new Cart();
	addSomeItemsToCart(store, cart);
	
	showCartTotalPrice(cart);

	addCart(store, cart);
	
	// clean exit
        System.exit(0);	
    }
    
    private static void addSomeItemsToCart(SaleService store, Cart cart) {
	final int count = Math.min(barcodeList.length, quantityList.length);
    
	for (int pos = 0; pos < count; pos++) {
	    final long barcode  = barcodeList[pos];
	    final int  quantity = quantityList[pos];
	    // Web Service Interface Call:
	    Product product = store.getProduct(Long.toString(barcode));
	    
	    Item item = new Item(product, quantity);
	    
	    System.out.print("Product name: " + product.getName()+"; ");
	    System.out.print("Item quantity: " + item.getQuantity()+ "; ");
	    System.out.print("Item Total: " + item.totalPrice()+ " credits; ");
	    
	    cart.addItem(item);
	    
	    System.out.println("Added to cart.");
	}
    }
    
    private static void addCart(SaleService store, Cart cart) {
    	
	//String registerID = Long.toString(SaleService.REGISTER_CODE);
	
	//Response response = store.addCart(registerID, cart);
	
	//System.out.println("Add cart response status: " + Response.Status.fromStatusCode(response.getStatus()));
	
	// Web Service Interface Call:
	String response = store.addCart(cart);
	System.out.println("Add cart response status: " + response);
    }
    
    private static void showCartTotalPrice(Cart cart) {
    	
    	// Web Service Interface Call:
	Long total = cart.totalPrice();
	
	System.out.println("Total price for cart: "+ total+ " credits.");
    }

}
